Memperbarui server SFTP

Anda dapat memperbarui pengguna yang diizinkan untuk terhubung ke server Cloud FTP dengan memperbarui konfigurasi akses server. Anda juga dapat memperbarui metadata seperti nama tampilan server.

Anda tidak dapat mengubah apakah server bersifat eksternal atau internal setelah server dibuat.

Peran yang diperlukan

Untuk mendapatkan izin yang diperlukan guna memperbarui server SFTP, minta administrator untuk memberi Anda peran IAM Cloud FTP Admin (roles/ftp.admin) di project Anda. Untuk mengetahui informasi selengkapnya tentang cara memberikan peran, lihat Mengelola akses ke project, folder, dan organisasi.

Peran bawaan ini berisi izin ftp.servers.update , yang diperlukan untuk memperbarui server SFTP.

Anda mungkin juga bisa mendapatkan izin ini dengan peran khusus atau peran bawaan lainnya.

Memperbarui akses untuk server eksternal

gcloud

Untuk memperbarui konfigurasi akses server eksternal, jalankan perintah gcloud alpha storage ftp servers update. Berikan flag --allowed-cidr-blocks.

Sebelum menggunakan salah satu data perintah di bawah, lakukan penggantian berikut:

  • SERVER_ID: ID server.
  • LOCATION_ID: lokasi server, seperti us-west1.
  • CIDR_BLOCK: blok CIDR yang diizinkan untuk mengakses server. Misalnya, 192.0.2.0/24. Anda harus memberikan setidaknya satu nilai, dan dapat memberikan maksimum 500 blok CIDR dalam daftar yang dipisahkan koma. Untuk mengizinkan koneksi dari semua alamat IP, gunakan 0.0.0.0/0.

Jalankan perintah berikut:

Linux, macOS, atau Cloud Shell

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID \
    --allowed-cidr-blocks=CIDR_BLOCK

Windows (PowerShell)

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID `
    --allowed-cidr-blocks=CIDR_BLOCK

Windows (cmd.exe)

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID ^
    --allowed-cidr-blocks=CIDR_BLOCK
Diperlukan waktu beberapa detik agar server diperbarui.

REST

Untuk memperbarui konfigurasi akses server eksternal, gunakan metode servers.patch. Di parameter kueri updateMask, berikan kolom externalConfig.

Sebelum menggunakan salah satu data permintaan, lakukan penggantian berikut:

  • PROJECT_ID: Google Cloud project ID server.
  • LOCATION_ID: lokasi server, seperti us-west1.
  • SERVER_ID: ID server.
  • CIDR_BLOCK: blok CIDR yang diizinkan untuk mengakses server. Misalnya, 192.0.2.0/24. Anda harus memberikan minimal satu nilai, dan dapat memberikan maksimum 500 blok CIDR . Untuk mengizinkan koneksi dari semua alamat IP, gunakan 0.0.0.0/0.

Metode HTTP dan URL:

PATCH https://ftp.googleapis.com/v1/projects/PROJECT_ID/locations/LOCATION_ID/servers/SERVER_ID?updateMask=externalConfig

Meminta isi JSON:

{
  "externalConfig": {
    "allowedCidrBlocks": [
      "CIDR_BLOCK"
    ]
  }
}

Untuk mengirim permintaan Anda, perluas salah satu opsi berikut:

Respons mengidentifikasi operasi yang berjalan lama. Diperlukan waktu beberapa detik agar server diperbarui.

Memperbarui akses untuk server internal

gcloud

Untuk memperbarui konfigurasi akses server internal, jalankan gcloud alpha storage ftp servers update perintah. Berikan flag --consumer-accept-list, dan jika perlu, berikan flag --consumer-reject-list.

Sebelum menggunakan salah satu data perintah di bawah, lakukan penggantian berikut:

  • SERVER_ID: ID server.
  • LOCATION_ID: lokasi server, seperti us-west1.
  • PROJECT_TO_ALLOW: project ID atau nomor project konsumen yang diizinkan untuk terhubung ke server menggunakan Private Service Connect. Misalnya, example-allowed-project. Anda harus menentukan setidaknya satu project.

    Anda dapat mengizinkan maksimum 500 project. Berikan beberapa project dan batas koneksinya masing-masing dalam daftar yang dipisahkan koma. Misalnya, --consumer-accept-list=projectA=20,projectB=15.

  • CONNECTION_LIMIT: jumlah maksimum endpoint Private Service Connect yang dapat dibuat di project konsumen. Nilai harus dari 1 hingga 250 endpoint.
  • (Opsional) PROJECT_TO_REJECT: project ID atau nomor project konsumen yang dilarang terhubung ke server. Contoh, example-rejected-project. Project dalam daftar ini ditolak untuk mengakses server meskipun project tersebut disertakan dalam daftar project yang diizinkan.

    Anda dapat menolak maksimum 64 project. Berikan beberapa project dalam daftar yang dipisahkan koma.

    Jika Anda tidak ingin menolak project secara eksplisit, hapus tanda --consumer-reject-list.

Jalankan perintah berikut:

Linux, macOS, atau Cloud Shell

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID \
    --consumer-accept-list=PROJECT_TO_ALLOW=CONNECTION_LIMIT \
    --consumer-reject-list=PROJECT_TO_REJECT

Windows (PowerShell)

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID `
    --consumer-accept-list=PROJECT_TO_ALLOW=CONNECTION_LIMIT `
    --consumer-reject-list=PROJECT_TO_REJECT

Windows (cmd.exe)

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID ^
    --consumer-accept-list=PROJECT_TO_ALLOW=CONNECTION_LIMIT ^
    --consumer-reject-list=PROJECT_TO_REJECT
Diperlukan waktu beberapa detik agar server diperbarui.

REST

Untuk memperbarui konfigurasi akses server internal, gunakan metode servers.patch. Di parameter kueri updateMask, berikan kolom internalConfig.

Sebelum menggunakan salah satu data permintaan, lakukan penggantian berikut:

  • PROJECT_ID: Google Cloud project ID server.
  • LOCATION_ID: lokasi server, seperti us-west1.
  • SERVER_ID: ID server.
  • PROJECT_TO_ALLOW: project ID atau nomor project konsumen yang diizinkan untuk terhubung ke server menggunakan Private Service Connect. Misalnya, example-allowed-project. Anda harus menentukan setidaknya satu project.

    Anda dapat mengizinkan maksimum 500 project.

  • CONNECTION_LIMIT: jumlah maksimum endpoint Private Service Connect yang dapat dibuat di project konsumen. Nilai harus dari 1 hingga 250 endpoint.
  • (Opsional) PROJECT_TO_REJECT: project ID atau nomor project konsumen yang dilarang terhubung ke server. Contoh, example-rejected-project. Project dalam daftar ini ditolak untuk mengakses server meskipun project tersebut disertakan dalam daftar project yang diizinkan.

    Anda dapat menolak maksimum 64 project.

    Jika Anda tidak ingin menolak project secara eksplisit, hapus objek consumerRejectList.

Metode HTTP dan URL:

PATCH https://ftp.googleapis.com/v1/projects/PROJECT_ID/locations/LOCATION_ID/servers/SERVER_ID?updateMask=internalConfig

Meminta isi JSON:

{
  "internalConfig": {
    "consumerAcceptList": [
      {
        "project": "projects/PROJECT_TO_ALLOW",
        "connectionLimit": CONNECTION_LIMIT
      }
    ],
    "consumerRejectList": [
      {
        "project": "projects/PROJECT_TO_REJECT"
      }
    ]
  }
}

Untuk mengirim permintaan Anda, perluas salah satu opsi berikut:

Respons mengidentifikasi operasi yang berjalan lama. Diperlukan waktu beberapa detik agar server diperbarui.

Memperbarui nama tampilan server

gcloud

Untuk memperbarui metadata seperti nama tampilan server SFTP, jalankan perintah gcloud alpha storage ftp servers update.

Sebelum menggunakan salah satu data perintah di bawah, lakukan penggantian berikut:

  • SERVER_ID: ID server.
  • LOCATION_ID: lokasi server, seperti us-west1.
  • DISPLAY_NAME: nama tampilan untuk server.

Jalankan perintah berikut:

Linux, macOS, atau Cloud Shell

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID \
    --display-name="DISPLAY_NAME"

Windows (PowerShell)

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID `
    --display-name="DISPLAY_NAME"

Windows (cmd.exe)

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID ^
    --display-name="DISPLAY_NAME"
Diperlukan waktu beberapa detik agar server diperbarui.

REST

Untuk memperbarui metadata seperti nama tampilan server SFTP, gunakan metode servers.patch. Di parameter kueri updateMask, berikan daftar kolom yang dipisahkan koma yang akan diperbarui. Dalam isi permintaan, berikan objek JSON dengan nilai yang akan ditetapkan.

Sebelum menggunakan salah satu data permintaan, lakukan penggantian berikut:

  • PROJECT_ID: Google Cloud project ID server.
  • LOCATION_ID: lokasi server, seperti us-west1.
  • SERVER_ID: ID server.
  • FIELDS_TO_UPDATE: daftar kolom yang dipisahkan koma yang akan diperbarui, relatif terhadap resource server. Misalnya, untuk memperbarui nama tampilan, berikan parameter kueri updateMask=displayName.
  • DISPLAY_NAME: nama tampilan untuk server.

Metode HTTP dan URL:

PATCH https://ftp.googleapis.com/v1/projects/PROJECT_ID/locations/LOCATION_ID/servers/SERVER_ID?updateMask=FIELDS_TO_UPDATE

Meminta isi JSON:

{
  "displayName": "DISPLAY_NAME"
}

Untuk mengirim permintaan Anda, perluas salah satu opsi berikut:

Respons mengidentifikasi operasi yang berjalan lama. Diperlukan waktu beberapa detik agar server diperbarui.